==============================
``psyclone.tests.lfric_build``
==============================

.. automodule:: psyclone.tests.lfric_build

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.lfric_build
